modulegraph
===========

modulegraph determines a dependency graph between Python modules primarily
by bytecode analysis for import statements.

modulegraph uses similar methods to modulefinder from the standard library,
but uses a more flexible internal representation, has more extensive
knowledge of special cases, and is extensible.

CI Status
---------

.. image:: https://github.com/ronaldoussoren/modulegraph/workflows/Lint/badge.svg
.. image:: https://github.com/ronaldoussoren/modulegraph/workflows/Test/badge.svg

Project links
-------------

* `Documentation <https://modulegraph.readthedocs.io/en/latest/>`_

* `Issue Tracker <https://github.com/ronaldoussoren/modulegraph/issues>`_

* `Repository <https://github.com/ronaldoussoren/modulegraph/>`_
